**********************************************************************************
*** Replication file for "Don't Stand So Close to Me: Spatial Contagion Effects and Party Competition"
***
*** Created: 3-13-14
***
*** Note: make sure to save the weights matrices, data set, and "Whitten and Williams AJPS--Programs.do" in the working directory!
**********************************************************************************

set matsize 1500
capture matrix drop _all

* Set up working directory
* cd ""

*************************************************************************************
*** Open the data and run the programs do file.
*************************************************************************************
do "Whitten and Williams AJPS--Programs.do"
use "Whitten and Williams AJPS.dta", clear

*********************************************************************************************
*** Descriptive statistics
*********************************************************************************************
*** Entire sample
preserve
	qui reg change lag_pervote rgdppc_growth gparties xregbet prime_dummy ciep_perc growth_govt pm_growth govt_lag_pervote govt_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par
	keep if e(sample)
	
	sum change lag_pervote rgdppc_growth majority gparties xregbet prime_dummy ciep_perc growth_govt pm_growth govt_lag_pervote govt_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par
	
	tab xregbet
	tab prime_dummy 
	tab gparties
	tab niche
	tab majority	
restore

*** High Clarity
preserve
	qui reg change lag_pervote rgdppc_growth gparties xregbet prime_dummy ciep_perc growth_govt pm_growth govt_lag_pervote govt_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 1, robust cluster(party)
	keep if e(sample)
	
	sum change lag_pervote rgdppc_growth majority gparties xregbet prime_dummy ciep_perc growth_govt pm_growth govt_lag_pervote govt_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par
	
	tab xregbet
	tab prime_dummy 
	tab gparties
	tab niche
	tab majority
restore

*** Low Clarity
preserve
	qui reg change lag_pervote rgdppc_growth gparties xregbet prime_dummy ciep_perc growth_govt pm_growth govt_lag_pervote govt_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 0, robust cluster(party)
	keep if e(sample)
	
	sum change lag_pervote rgdppc_growth majority gparties xregbet prime_dummy ciep_perc growth_govt pm_growth govt_lag_pervote govt_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par
	
	tab xregbet
	tab prime_dummy 
	tab gparties
	tab niche
	tab majority
restore

*********************************************************************************************
*** Replication Models
*** W: Absolute distance from closest neighbors
*********************************************************************************************
* High clarity cases
preserve
	qui reg change lag_pervote rgdppc_growth gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 1
	keep if e(sample)
	global rhs "rgdppc_growth prime_dummy xregbet pm_growth growth_govt lag_pervote party_shift_t party_shift_t1 niche gparties ciep_perc pm_lag_pervote niche_lag_pervote pm_gparties pm_ciep govt_ciep eff_par"
	local w "prox_abs_high_clarity_weight2"
	spatwmat using "`w'.dta", name(`w') eigenval(E_`w')
	spatgsa change, w(`w') m g two
	qui reg change lag_pervote rgdppc_growth gparties xregbet prime_dummy ciep_perc pm_growth growth_govt pm_lag_pervote pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 1
	ols_ar2
	spatdiag, weights(`w')
	spatreg change $rhs, weights(`w') eigenval(E_`w') model(lag) 
	me_sarh
	get_me
	sr_fit, dv(change) rhs($rhs) w(`w')
	draws, d(1000) name(`w'_draws)
	mat b = e(b)
	svmat b, name(b)
	keep in 1
	outsheet b* using "b_`w'.csv", comma replace
restore

* Low clarity cases
preserve
	qui reg change lag_pervote rgdppc_growth majority gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_majority pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 0
	keep if e(sample)
	global rhs "rgdppc_growth prime_dummy xregbet pm_growth growth_govt lag_pervote party_shift_t party_shift_t1 niche majority gparties ciep_perc pm_lag_pervote niche_lag_pervote pm_majority pm_gparties pm_ciep govt_ciep eff_par"
	local w "prox_abs_low_clarity_weight2"
	spatwmat using "`w'.dta", name(`w') eigenval(E_`w')
	spatgsa change, w(`w') m g two
	qui reg change lag_pervote rgdppc_growth majority gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_majority pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 0
	ols_ar2
	spatdiag, weights(`w')
	spatreg change $rhs, weights(`w') eigenval(E_`w') model(lag)
	me_sarl
	get_me
	sr_fit, dv(change) rhs($rhs) w(`w')
	draws, d(1000) name(`w'_draws)
	outsheet using "x_`w'.csv", comma replace 
	mat b = e(b)
	svmat b, name(b)
	keep in 1
	outsheet b* using "b_`w'.csv", comma replace
restore

*********************************************************************************************
*** Supplemental Information Document
*********************************************************************************************

*********************************************************************************************
*** Alternative Spatial Specifications
*********************************************************************************************
* All parties, absolute distance: high clarity
preserve
	qui reg change lag_pervote rgdppc_growth gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 1
	keep if e(sample)
	global rhs "rgdppc_growth prime_dummy xregbet pm_growth growth_govt lag_pervote party_shift_t party_shift_t1 niche gparties ciep_perc pm_lag_pervote niche_lag_pervote pm_gparties pm_ciep govt_ciep eff_par"
	local w "high_clarity_weight2"
	spatwmat using "`w'.dta", name(`w') eigenval(E_`w')
	spatgsa change, w(`w') m g two
	qui reg change lag_pervote rgdppc_growth gparties xregbet prime_dummy ciep_perc pm_growth growth_govt pm_lag_pervote pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 1
	ols_ar2
	spatdiag, weights(`w')
	spatreg change $rhs, weights(`w') eigenval(E_`w') model(lag)
	get_me
	me_sarh
	sr_fit, dv(change) rhs($rhs) w(`w')
restore

* All parties, absolute distance: low clarity
preserve
	qui reg change lag_pervote rgdppc_growth majority gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_majority pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 0
	keep if e(sample)
	global rhs "rgdppc_growth prime_dummy xregbet pm_growth growth_govt lag_pervote party_shift_t party_shift_t1 niche majority gparties ciep_perc pm_lag_pervote niche_lag_pervote pm_majority pm_gparties pm_ciep govt_ciep eff_par"
	local w "low_clarity_weight2"
	spatwmat using "`w'.dta", name(`w') eigenval(E_`w')
	spatgsa change, w(`w') m g two
	qui reg change lag_pervote rgdppc_growth majority gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_majority pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 0
	ols_ar2
	spatdiag, weights(`w')
	spatreg change $rhs, weights(`w') eigenval(E_`w') model(lag)
	get_me
	me_sarl
	sr_fit, dv(change) rhs($rhs) w(`w')
restore

* All parties, quadratic distance: high clarity
preserve
	qui reg change lag_pervote rgdppc_growth gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 1
	keep if e(sample)
	global rhs "rgdppc_growth prime_dummy xregbet pm_growth growth_govt lag_pervote party_shift_t party_shift_t1 niche gparties ciep_perc pm_lag_pervote niche_lag_pervote pm_gparties pm_ciep govt_ciep eff_par"
	local w "sq_high_clarity_weight2"
	spatwmat using "`w'.dta", name(`w') eigenval(E_`w')
	spatgsa change, w(`w') m g two
	qui reg change lag_pervote rgdppc_growth gparties xregbet prime_dummy ciep_perc pm_growth growth_govt pm_lag_pervote pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 1
	ols_ar2
	spatdiag, weights(`w')
	spatreg change $rhs, weights(`w') eigenval(E_`w') model(lag)
	get_me
	me_sarh
	sr_fit, dv(change) rhs($rhs) w(`w')
restore

* All parties, quadratic distance: low clarity
preserve
	qui reg change lag_pervote rgdppc_growth majority gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_majority pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 0
	keep if e(sample)
	global rhs "rgdppc_growth prime_dummy xregbet pm_growth growth_govt lag_pervote party_shift_t party_shift_t1 niche majority gparties ciep_perc pm_lag_pervote niche_lag_pervote pm_majority pm_gparties pm_ciep govt_ciep eff_par"
	local w "sq_low_clarity_weight2"
	spatwmat using "`w'.dta", name(`w') eigenval(E_`w')
	spatgsa change, w(`w') m g two
	qui reg change lag_pervote rgdppc_growth majority gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_majority pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 0
	ols_ar2
	spatdiag, weights(`w')
	spatreg change $rhs, weights(`w') eigenval(E_`w') model(lag)
	get_me
	me_sarl
	sr_fit, dv(change) rhs($rhs) w(`w')
restore

* Contiguous parties, quadratic distance: high clarity
preserve
	qui reg change lag_pervote rgdppc_growth gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 1
	keep if e(sample)
	global rhs "rgdppc_growth prime_dummy xregbet pm_growth growth_govt lag_pervote party_shift_t party_shift_t1 niche gparties ciep_perc pm_lag_pervote niche_lag_pervote pm_gparties pm_ciep govt_ciep eff_par"
	local w "prox_sq_high_clarity_weight2"
	spatwmat using "`w'.dta", name(`w') eigenval(E_`w')
	spatgsa change, w(`w') m g two
	qui reg change lag_pervote rgdppc_growth gparties xregbet prime_dummy ciep_perc pm_growth growth_govt pm_lag_pervote pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 1
	ols_ar2
	spatdiag, weights(`w')
	spatreg change $rhs, weights(`w') eigenval(E_`w') model(lag)
	get_me
	me_sarh
	sr_fit, dv(change) rhs($rhs) w(`w')
restore

* Contiguous parties, quadratic distance: low clarity
preserve
	qui reg change lag_pervote rgdppc_growth majority gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_majority pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 0
	keep if e(sample)
	global rhs "rgdppc_growth prime_dummy xregbet pm_growth growth_govt lag_pervote party_shift_t party_shift_t1 niche majority gparties ciep_perc pm_lag_pervote niche_lag_pervote pm_majority pm_gparties pm_ciep govt_ciep eff_par"
	local w "prox_sq_low_clarity_weight2"
	spatwmat using "`w'.dta", name(`w') eigenval(E_`w')
	spatgsa change, w(`w') m g two
	qui reg change lag_pervote rgdppc_growth majority gparties xregbet prime_dummy ciep_perc growth_govt pm_growth pm_lag_pervote pm_majority pm_gparties govt_ciep niche niche_lag_pervote party_shift_t party_shift_t1 pm_ciep eff_par if clear1 == 0
	ols_ar2
	spatdiag, weights(`w')
	spatreg change $rhs, weights(`w') eigenval(E_`w') model(lag)
	get_me 
	me_sarl
	sr_fit, dv(change) rhs($rhs) w(`w')
restore



